@@ -5,11 +5,14 @@
  * libpng license (see LICENSE, in pngcrush.c).
  */
 
-/* Special defines for pngcrush version 1.8.2 */
+/* Special defines for pngcrush version 1.8.5 */
 
 #ifndef PNGCRUSH_H
 #define PNGCRUSH_H
 
+#define PNG_READ_SUPPORTED
+#define PNG_WRITE_SUPPORTED
+
 /* Do not build stuff we will not use */
 #undef PNG_BUILD_GRAYSCALE_PALETTE_SUPPORTED
 #undef PNG_CONVERT_tIME_SUPPORTED
